# zood

zood 是一个辅助文档生成的Python库, zood的页面风格更倾向于纯文档内容而非博客

## 主题预览

[![20230101121438](https://raw.githubusercontent.com/learner-lu/picbed/master/20230101121438.png)](https://luzhixing12345.github.io/zood/)

## 安装与使用

```bash
pip install zood
```

参见 [用户使用文档](https://luzhixing12345.github.io/zood/)

## 参考

- [UI](https://remixicon.com/)